@@ -74,7 +74,7 @@ class BatchedBrownianTree:
         t0, t1, self.sign = self.sort(t0, t1)
         w0 = kwargs.get("w0", torch.zeros_like(x))
         if seed is None:
-            seed = torch.randint(0, 2**63 - 1, []).item()
+            seed = torch.randint(0, 2**63 - 1, [], device="cpu").item()
         self.batched = True
         try:
             assert len(seed) == x.shape[0]
@@ -412,7 +412,7 @@ def log_likelihood(
 ):
     extra_args = {} if extra_args is None else extra_args
     s_in = x.new_ones([x.shape[0]])
-    v = torch.randint_like(x, 2) * 2 - 1
+    v = torch.randint_like(x, 2, device="cpu") * 2 - 1
     fevals = 0
 
     def ode_fn(sigma, x):
@@ -798,8 +798,12 @@ def sample_dpmpp_2s_ancestral(
     extra_args = {} if extra_args is None else extra_args
     noise_sampler = default_noise_sampler(x) if noise_sampler is None else noise_sampler
     s_in = x.new_ones([x.shape[0]])
-    sigma_fn = lambda t: t.neg().exp()
-    t_fn = lambda sigma: sigma.to("cpu").log().neg().to(x.device)
+
+    def sigma_fn(t):
+        return t.neg().exp()
+
+    def t_fn(sigma):
+        return sigma.to("cpu").log().neg().to(x.device)
 
     for i in trange(len(sigmas) - 1, disable=disable):
         denoised = model(x, sigmas[i] * s_in, **extra_args)
@@ -856,8 +860,12 @@ def sample_dpmpp_sde(
     )
     extra_args = {} if extra_args is None else extra_args
     s_in = x.new_ones([x.shape[0]])
-    sigma_fn = lambda t: t.neg().exp()
-    t_fn = lambda sigma: sigma.to("cpu").log().neg().to(x.device)
+
+    def sigma_fn(t):
+        return t.neg().exp()
+
+    def t_fn(sigma):
+        return sigma.to("cpu").log().neg().to(x.device)
 
     for i in trange(len(sigmas) - 1, disable=disable):
         denoised = model(x, sigmas[i] * s_in, **extra_args)
@@ -906,8 +914,13 @@ def sample_dpmpp_2m(model, x, sigmas, extra_args=None, callback=None, disable=No
     """DPM-Solver++(2M)."""
     extra_args = {} if extra_args is None else extra_args
     s_in = x.new_ones([x.shape[0]])
-    sigma_fn = lambda t: t.neg().exp()
-    t_fn = lambda sigma: sigma.to("cpu").log().neg().to(x.device)
+
+    def sigma_fn(t):
+        return t.neg().exp()
+
+    def t_fn(sigma):
+        return sigma.to("cpu").log().neg().to(x.device)
+
     old_denoised = None
 
     for i in trange(len(sigmas) - 1, disable=disable):
